@@ -27,14 +27,14 @@ import sipconfig, PyQt4.pyqtconfig
 
 # These are installation specific values created when PyKDE was configured.
 # 
-kde_version_parts = '4.14.26'.split('.')
+kde_version_parts = '4.14.30'.split('.')
 kde_version_hex = int(kde_version_parts[0])*65536 + int(kde_version_parts[1])*256 + int(kde_version_parts[2])
 _pkg_config = {
     'dist_name':            '',
     'kde_version':          kde_version_hex,
     'kde_version_extra':    '',
     'kde_version_sfx':      '',
-    'kde_version_str':      '4.14.26',
+    'kde_version_str':      '4.14.30',
     'kdebasedir':           '/usr',
     'kdeincdir':            '/usr/include/kde4',
     'kdelibdir':            '/usr/lib',
@@ -43,9 +43,9 @@ _pkg_config = {
     'pykde_kde_sip_flags':  ' -t ALL -t WS_X11 -t Qt_4_8_6  -X VendorID -X PyQt_NoPrintRangeBug -P;-g;-x;PyKDE_QVector;-x;PyKDE_GLuint',
     'pykde_mod_dir':        '/usr/lib/python3.6/site-packages/PyKDE4',
     'pykde_modules':        '',
-    'pykde_sip_dir':        '/usr/share/python3-sip/PyKDE4',
+    'pykde_sip_dir':        '/usr/share/sip/PyKDE4',
     'pykde_version':        kde_version_hex,
-    'pykde_version_str':    '4.14.26'
+    'pykde_version_str':    '4.14.30'
 }
 
 _default_macros = None
